# Sandlercubics

> Digitized cubic equations of state from Sandler's 5th ed.

Sandlercubics implements a Python interface to the cubic equations of state found in  _Chemical, Biochemical, and Engineering Thermodynamics_ (5th edition) by Stan Sandler (Wiley, USA). It should be used for educational purposes only.

For full documentation, see [https://sandlercubics.readthedocs.io/en/stable/index.html](https://sandlercubics.readthedocs.io/en/stable/index.html)